@@ -562,7 +562,7 @@ class FrameDump():
         s = self._cam._image_properties["stride"]     # bytes
         h = self._cam._image_properties["height"]     # pixels
         count = self._cam._image_buffer.shape[0]//imgsize
-        n = min(count, frame_count_max)                    
+        n = min(count, frame_count)                    
         # View the buffer as separate byte blocks for each image
         buffer = self._cam._image_buffer.reshape((count, imgsize + postpad))[:,:imgsize]
         # Metadata may be present at end of each image data block
